pub struct DriftError {
pub position: usize,
pub expected: String,
pub found: Option<String>,
}Expand description
A generated inventory and the document it was generated from disagree.
Generated code names operations by position in the inventory it was emitted
from. Document::matches is what makes that positional promise true for a
document read at run time, and this is what it says when it is not.
Fields
position: usizeexpected: Stringfound: Option<String>Trait Implementations
Sourceimpl Clone for DriftError
impl Clone for DriftError
Sourcefn clone(&self) -> DriftError
fn clone(&self) -> DriftError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DriftError
impl Debug for DriftError
Sourceimpl Display for DriftError
impl Display for DriftError
impl Eq for DriftError
Sourceimpl Error for DriftError
impl Error for DriftError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<DriftError> for Error
impl From<DriftError> for Error
Sourcefn from(source: DriftError) -> Self
fn from(source: DriftError) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for DriftError
impl PartialEq for DriftError
impl StructuralPartialEq for DriftError